@@ -3,7 +3,7 @@ BEGIN {
   $Syccess::Validator::Required::AUTHORITY = 'cpan:GETTY';
 }
 # ABSTRACT: A validator to check for a required field
-$Syccess::Validator::Required::VERSION = '0.003';
+$Syccess::Validator::Required::VERSION = '0.004';
 use Moo;
 
 with qw(
@@ -14,7 +14,9 @@ has message => (
   is => 'lazy',
 );
 
-sub _build_message { '%s is required.' }
+sub _build_message {
+  return '%s is required.';
+}
 
 sub validate {
   my ( $self, %params ) = @_;
@@ -37,7 +39,7 @@ Syccess::Validator::Required - A validator to check for a required field
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
